package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.EmsFacsAbility;

/**
 * 能源设施能力Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-22
 */
public interface EmsFacsAbilityMapper
{
    /**
     * 查询能源设施能力
     * 
     * @param id 能源设施能力主键
     * @return 能源设施能力
     */
     EmsFacsAbility selectEmsFacsAbilityById(Long id);

    /**
     * 查询能源设施能力列表
     * 
     * @param emsFacsAbility 能源设施能力
     * @return 能源设施能力集合
     */
     List<EmsFacsAbility> selectEmsFacsAbilityList(EmsFacsAbility emsFacsAbility);

    /**
     * 新增能源设施能力
     * 
     * @param emsFacsAbility 能源设施能力
     * @return 结果
     */
     int insertEmsFacsAbility(EmsFacsAbility emsFacsAbility);

    /**
     * 新增能源设施能力
     *
     * @param list 能源设施能力list
     * @return 结果
     */
    int insertEmsFacsAbilityBatch(List<EmsFacsAbility> list);

    /**
     * 修改能源设施能力
     * 
     * @param emsFacsAbility 能源设施能力
     * @return 结果
     */
     int updateEmsFacsAbility(EmsFacsAbility emsFacsAbility);

    /**
     * 删除能源设施能力
     * 
     * @param id 能源设施能力主键
     * @return 结果
     */
     int deleteEmsFacsAbilityById(Long id);

    /**
     * 批量删除能源设施能力
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteEmsFacsAbilityByIds(Long[] ids);

    /**
     * 根据设施code删除
     *
     * @param facsCode 设施编码
     * @return 结果
     */
    int deleteEmsFacsAbilityFacsCode(String facsCode);
}
